%define module pyparsing

# when bootstrapping Python 3, pyparsing needs to be rebuilt before depndency generator is available
%bcond_without bootstrap

%if ! %{with bootstrap}
%global build_wheel 1
%global python_wheelname %{module}-%{version}-py2.py3-none-any.whl
%endif

Summary:        A general parsing module for Python
Name:           python-%{module}
Version:        3.1.1
Release:        %mkrel 1
License:        MIT
Group:          Development/Python
URL:            https://pypi.org/project/pyparsing/
Source0:        https://pypi.io/packages/source/p/%{module}/%{module}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(flit-core)

%if ! %{with bootstrap}
BuildRequires:  python3dist(sphinx)
%endif

%if 0%{?build_wheel}
BuildRequires:  python3dist(pip)
BuildRequires:  python3dist(wheel)
%endif

%description
The pyparsing module is an alternative approach to creating and executing
simple grammars, vs. the traditional lex/yacc approach, or the use of regular
expressions. The pyparsing module provides a library of classes that client
code uses to construct the grammar directly in Python code.

%package -n python3-%{module}
Summary:        A general parsing module for Python 3
Group:          Development/Python
%{?python_provide:%python_provide python3-%{module}}
%if %{with bootstrap}
Provides:       python%{python3_pkgversion}dist(pyparsing) = %{version}
Provides:       python%{python3_version}dist(pyparsing) = %{version}
%endif

%description -n python3-%{module}
The pyparsing module is an alternative approach to creating and executing
simple grammars, vs. the traditional lex/yacc approach, or the use of regular
expressions. The pyparsing module provides a library of classes that client
code uses to construct the grammar directly in Python code.

%prep
%setup -q -n %{module}-%{version}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%if ! %{with bootstrap}
# build docs
pushd docs
# Theme is not available
sed -i '/alabaster/d' conf.py
sphinx-build -b html . html
popd
%endif

%install
%pyproject_install
%pyproject_save_files %{module}

%files -n python3-%{module} -f %{pyproject_files}
%doc CHANGES README.rst
%if ! %{with bootstrap}
%doc docs/html examples
%endif
%license LICENSE


%changelog
* Wed Mar 06 2024 daviddavid <daviddavid> 3.1.1-1.mga10
+ Revision: 2047747
- new version: 3.1.1

* Thu Dec 07 2023 wally <wally> 3.0.9-3.mga10
+ Revision: 2015069
- bootstrap build for py3.12
- rebuild for py3.12

* Mon Oct 31 2022 papoteur <papoteur> 3.0.9-2.mga9
+ Revision: 1900695
- new 3.0.9, build without bootstrap

* Mon Oct 31 2022 papoteur <papoteur> 3.0.9-1.mga9
+ Revision: 1900694
- new 3.0.9, build with bootstrap

* Wed Mar 23 2022 umeabot <umeabot> 3.0.7-2.mga9
+ Revision: 1822100
- Mageia 9 Mass Rebuild

* Sat Feb 05 2022 wally <wally> 3.0.7-1.mga9
+ Revision: 1771635
- new version 3.0.7
- bootstrap build for python 3.10

* Sun Mar 14 2021 wally <wally> 2.4.7-3.mga9
+ Revision: 1702514
- bootstrap build for new python 3.9

* Sat Mar 13 2021 wally <wally> 2.4.7-2.mga9
+ Revision: 1702252
- add conditionals for bootstrapping (sync with Fedora)

* Thu Sep 10 2020 guillomovitch <guillomovitch> 2.4.7-1.mga8
+ Revision: 1624282
- new version 2.4.7

* Sun Feb 16 2020 umeabot <umeabot> 2.4.2-3.mga8
+ Revision: 1535280
- Mageia 8 Mass Rebuild

* Fri Oct 11 2019 tv <tv> 2.4.2-2.mga8
+ Revision: 1451718
- rebuild with python 3.8

* Thu Sep 05 2019 wally <wally> 2.4.2-1.mga8
+ Revision: 1437613
- new version 2.4.2
- drop python2 support
- rebuild for python3.8

* Sat Jan 05 2019 wally <wally> 2.2.0-4.mga7
+ Revision: 1349249
- rebuild for python3.7

* Thu Sep 20 2018 umeabot <umeabot> 2.2.0-3.mga7
+ Revision: 1289788
- Mageia 7 Mass Rebuild

* Mon Feb 19 2018 daviddavid <daviddavid> 2.2.0-2.mga7
+ Revision: 1203224
- python-pyparsing has been renamed so don't forget to provide/obsolete it

* Mon Feb 19 2018 kekepower <kekepower> 2.2.0-1.mga7
+ Revision: 1203146
- Update to version 2.2.0

* Sat Jul 29 2017 philippem <philippem> 2.1.10-1.mga7
+ Revision: 1132567
- add BR on python-pkg-resources
- update to 2.1.10

* Tue May 17 2016 philippem <philippem> 2.1.4-1.mga6
+ Revision: 1016376
- update to 2.1.4

* Thu May 12 2016 philippem <philippem> 2.1.3-1.mga6
+ Revision: 1013956
- update to 2.1.3

* Wed May 11 2016 philippem <philippem> 2.1.2-1.mga6
+ Revision: 1013636
- update to 2.1.2

* Mon Apr 11 2016 philippem <philippem> 2.1.1-1.mga6
+ Revision: 1000205
- update to 2.1.1

* Mon Jan 18 2016 daviddavid <daviddavid> 2.0.7-1.mga6
+ Revision: 925574
- new version: 2.0.7
- update Source URL

* Wed Oct 07 2015 daviddavid <daviddavid> 2.0.1-9.mga6
+ Revision: 886858
- use new python macros
+ tv <tv>
- rebuild for python 3.5

* Wed Oct 15 2014 umeabot <umeabot> 2.0.1-8.mga5
+ Revision: 747799
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.0.1-7.mga5
+ Revision: 729491
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.0.1-6.mga5
+ Revision: 688268
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 2.0.1-5.mga5
+ Revision: 628957
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 2.0.1-4.mga4
+ Revision: 544063
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.0.1-3.mga4
+ Revision: 499264
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Oct 07 2013 philippem <philippem> 2.0.1-2.mga4
+ Revision: 492443
+ rebuild (emptylog)

* Wed Oct 02 2013 philippem <philippem> 2.0.1-1.mga4
+ Revision: 490551
- Update to 2.0.1

* Thu Aug 29 2013 fwang <fwang> 1.5.6-1.mga4
+ Revision: 472768
- new version 1.5.6

* Sun Jan 13 2013 umeabot <umeabot> 1.5.5-4.mga3
+ Revision: 379387
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Mar 12 2012 kamil <kamil> 1.5.5-3.mga3
+ Revision: 222874
- build python3-pyparsing

* Fri May 13 2011 ahmad <ahmad> 1.5.5-2.mga1
+ Revision: 97796
- Add provides pyparsing

* Fri May 13 2011 ahmad <ahmad> 1.5.5-1.mga1
+ Revision: 97778
- imported package python-pyparsing

